@@ -5,7 +5,16 @@
 #include <sys/mount.h>
 #include <sys/stat.h>
 
+#ifdef __NetBSD__
+#include <sys/types.h>
+#include <sys/statvfs.h>
+#define statfs statvfs
+#define f_flags f_flag
+#define f_bsize f_frsize
+#endif
+
 #ifdef __FreeBSD__
+#if __has_include(<libgeom.h>)
 #include <libgeom.h>
 
 static const char* detectFsLabel(struct statfs* fs, FFDisk* disk)
@@ -27,7 +36,7 @@ static const char* detectFsLabel(struct statfs* fs, FFDisk* disk)
             return "geom_gettree() failed";
         }
 
-        for (cLabels = geomTree.lg_class.lh_first; !ffStrEquals(cLabels->lg_name, "LABEL"); cLabels = cLabels->lg_class.le_next);
+        for (cLabels = geomTree.lg_class.lh_first; cLabels && !ffStrEquals(cLabels->lg_name, "LABEL"); cLabels = cLabels->lg_class.le_next);
         if (!cLabels)
             return "Class LABEL is not found";
     }
@@ -42,6 +51,12 @@ static const char* detectFsLabel(struct statfs* fs, FFDisk* disk)
 
     return NULL;
 }
+#else
+static const char* detectFsLabel(FF_MAYBE_UNUSED struct statfs* fs, FF_MAYBE_UNUSED FFDisk* disk)
+{
+    return "Fastfetch was compiled without libgeom support";
+}
+#endif
 
 static void detectFsInfo(struct statfs* fs, FFDisk* disk)
 {
@@ -51,7 +66,7 @@ static void detectFsInfo(struct statfs* fs, FFDisk* disk)
             ? FF_DISK_VOLUME_TYPE_REGULAR_BIT
             : FF_DISK_VOLUME_TYPE_SUBVOLUME_BIT;
     }
-    else if(ffStrbufStartsWithS(&disk->mountpoint, "/boot") || ffStrbufStartsWithS(&disk->mountpoint, "/efi"))
+    else if(fs->f_flags & MNT_IGNORE)
         disk->type = FF_DISK_VOLUME_TYPE_HIDDEN_BIT;
     else if(!(fs->f_flags & MNT_LOCAL))
         disk->type = FF_DISK_VOLUME_TYPE_EXTERNAL_BIT;
@@ -92,27 +107,48 @@ void detectFsInfo(struct statfs* fs, FFDisk* disk)
     }, &attrBuf, sizeof(attrBuf), 0) == 0)
         ffStrbufInitNS(&disk->name, attrBuf.nameRef.attr_length - 1 /* excluding '\0' */, attrBuf.nameSpace);
 }
+#else
+static void detectFsInfo(struct statfs* fs, FFDisk* disk)
+{
+    #ifdef MNT_IGNORE
+    if(fs->f_flags & MNT_IGNORE)
+        disk->type = FF_DISK_VOLUME_TYPE_HIDDEN_BIT;
+    else
+    #endif
+    if(!(fs->f_flags & MNT_LOCAL))
+        disk->type = FF_DISK_VOLUME_TYPE_EXTERNAL_BIT;
+    else
+        disk->type = FF_DISK_VOLUME_TYPE_REGULAR_BIT;
+}
 #endif
 
 const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
 {
+    #ifndef __NetBSD__
     int size = getfsstat(NULL, 0, MNT_WAIT);
-
-    if(size <= 0)
-        return "getfsstat(NULL, 0, MNT_WAIT) failed";
+    if(size <= 0) return "getfsstat(NULL, 0, MNT_WAIT) failed";
+    #else
+    int size = getvfsstat(NULL, 0, ST_WAIT);
+    if(size <= 0) return "getvfsstat(NULL, 0, ST_WAIT) failed";
+    #endif
 
     FF_AUTO_FREE struct statfs* buf = malloc(sizeof(*buf) * (unsigned) size);
+    #ifndef __NetBSD__
     if(getfsstat(buf, (int) (sizeof(*buf) * (unsigned) size), MNT_NOWAIT) <= 0)
         return "getfsstat(buf, size, MNT_NOWAIT) failed";
+    #else
+    if(getvfsstat(buf, sizeof(*buf) * (unsigned) size, ST_NOWAIT) <= 0)
+        return "getvfsstat(buf, size, ST_NOWAIT) failed";
+    #endif
 
     for(struct statfs* fs = buf; fs < buf + size; ++fs)
     {
-        if(__builtin_expect(options->folders.length, 0))
+        if(__builtin_expect(options->folders.length > 0, 0))
         {
-            if(!ffDiskMatchMountpoint(options, fs->f_mntonname))
+            if(!ffDiskMatchMountpoint(&options->folders, fs->f_mntonname))
                 continue;
         }
-        else if(!ffStrStartsWith(fs->f_mntfromname, "/dev/") && !ffStrEquals(fs->f_fstypename, "zfs"))
+        else if(!ffStrEquals(fs->f_mntonname, "/") && !ffStrStartsWith(fs->f_mntfromname, "/dev/") && !ffStrEquals(fs->f_fstypename, "zfs") && !ffStrEquals(fs->f_fstypename, "fusefs.sshfs"))
             continue;
 
         #ifdef __FreeBSD__
@@ -123,13 +159,13 @@ const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
 
         FFDisk* disk = ffListAdd(disks);
 
-        disk->bytesTotal = (uint64_t)fs->f_blocks * fs->f_bsize;
-        disk->bytesFree = (uint64_t)fs->f_bfree * fs->f_bsize;
-        disk->bytesAvailable = (uint64_t)fs->f_bavail * fs->f_bsize;
+        disk->bytesTotal = (uint64_t)fs->f_blocks * (uint64_t)fs->f_bsize;
+        disk->bytesFree = (uint64_t)fs->f_bfree * (uint64_t)fs->f_bsize;
+        disk->bytesAvailable = (uint64_t)fs->f_bavail * (uint64_t)fs->f_bsize;
         disk->bytesUsed = 0; // To be filled in ./disk.c
 
         disk->filesTotal = (uint32_t) fs->f_files;
-        disk->filesUsed = (uint32_t) (disk->filesTotal - (uint64_t)fs->f_ffree);
+        disk->filesUsed = (uint32_t) fs->f_files - (uint32_t) fs->f_ffree;
 
         ffStrbufInitS(&disk->mountFrom, fs->f_mntfromname);
         ffStrbufInitS(&disk->mountpoint, fs->f_mntonname);
@@ -143,9 +179,14 @@ const char* ffDetectDisksImpl(FFDiskOptions* options, FFlist* disks)
         if(fs->f_flags & MNT_RDONLY)
             disk->type |= FF_DISK_VOLUME_TYPE_READONLY_BIT;
 
+        #ifdef __OpenBSD__
+        #define st_birthtimespec __st_birthtim
+        #endif
+        #ifndef __DragonFly__
         struct stat st;
         if(stat(fs->f_mntonname, &st) == 0 && st.st_birthtimespec.tv_sec > 0)
-            disk->createTime = (uint64_t)((st.st_birthtimespec.tv_sec * 1000) + (st.st_birthtimespec.tv_nsec / 1000000));
+            disk->createTime = (uint64_t)(((uint64_t) st.st_birthtimespec.tv_sec * 1000) + ((uint64_t) st.st_birthtimespec.tv_nsec / 1000000));
+        #endif
     }
 
     return NULL;
